utils

package
v0.0.0-...-d92d8b1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 22, 2023 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func LoggedError

func LoggedError(ctx context.Context, hintCode constants.HintCode, err error) *models.Error

func ReadUserIP

func ReadUserIP(r *http.Request) string

Types

type CustomTime

type CustomTime struct {
	// We have non-default time format in unserialized json, so we need custom time.
	// Hence, this time is not scannable by sql driver, so we should use both custom and default time in DTO struct.
	time.Time
}

func (*CustomTime) UnmarshalJSON

func (t *CustomTime) UnmarshalJSON(b []byte) error

Jump to