Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LoggedError ¶
func ReadUserIP ¶
Types ¶
type CustomTime ¶
type CustomTime struct {
// We have non-default time format in unserialized json, so we need custom time.
// Hence, this time is not scannable by sql driver, so we should use both custom and default time in DTO struct.
time.Time
}
func (*CustomTime) UnmarshalJSON ¶
func (t *CustomTime) UnmarshalJSON(b []byte) error
Click to show internal directories.
Click to hide internal directories.